@@ -650,6 +650,43 @@ class TestUSPSEndicia(BaseTestCase):
                     [endicia_mailclass], argument
                 )
 
+    def test_0030_endicia_shipping_rates(self):
+        """
+        Tests get_endicia_shipping_rates method.
+        """
+        with Transaction().start(DB_NAME, USER, context=CONTEXT):
+            self.setup_defaults()
+
+            with Transaction().set_context(company=self.company.id):
+
+                # Create sale order
+                sale, = self.Sale.create([{
+                    'reference': 'S-1001',
+                    'payment_term': self.payment_term,
+                    'party': self.sale_party.id,
+                    'invoice_address': self.sale_party.addresses[0].id,
+                    'shipment_address': self.sale_party.addresses[0].id,
+                    'lines': [
+                        ('create', [{
+                            'type': 'line',
+                            'quantity': 1,
+                            'product': self.product,
+                            'unit_price': Decimal('10.00'),
+                            'description': 'Test Description1',
+                            'unit': self.product.template.default_uom,
+                        }]),
+                    ]
+                }])
+
+                self.StockLocation.write([sale.warehouse], {
+                    'address': self.company.party.addresses[0].id,
+                })
+
+                self.assertEqual(len(sale.lines), 1)
+
+            with Transaction().set_context(sale=sale):
+                self.assertGreater(len(self.carrier.get_rates()), 0)
+
 
 def suite():
     suite = trytond.tests.test_tryton.suite()
